# Marmoset Electrocorticography – Annotations of Electrodes

Authors: Ken Nakae<sup>1</sup>, Misako Komatsu<sup>2</sup>*, Takaaki Kaneko<sup>3,4,5</sup>, Junichi Hata<sup>3,4,5</sup>, Hideyuki Okano<sup>3,4</sup>, Shin Ishii<sup>1</sup>, Tetsuo Yamamori<sup>2</sup>

1. Integrated Systems Biology Laboratory (Ishii Laboratory), Division of Systems Informatics, Department of Systems Science, Graduate School of Informatics, Kyoto University
2. Laboratory for Molecular Analysis of Higher Brain Function, RIKEN Center for Brain Science
3. Laboratory for Marmoset Neural Architecture, RIKEN Center for Brain Science
4. Department of Physiology (Okano Lab), Keio University School of Medicine, Keio University School of Medicine
5. Central Institute for Experimental Animals

*corresponding author: Misako Komatsu (mskkomatsu@gmail.com)

## DATASET DESCRIPTION

This dataset provides annotated electrode layouts for the animals that participated in ECoG experiments.


### Method

The positions of electrodes of the electrocorticography (ECoG) for marmosets are normalized to the standard space, which is defined using the standard brain [BMA 2019 Ex vivo](https://dataportal.brainminds.jp/atlas-package-download-main-page/bma-2019-ex-vivo).

This normalization consists of two steps:

1. electrode identification on the individual in vivo MRI (subject space)
2. registration to the averaged ex vivo MRI (standard space). Here, we explain these two steps.

<br/>

#### 1. Electrode identification on the subject space

![](docs/Annotation1.png)

We obtain a computed tomography (CT) scan image of individual marmoset after an electrode implantation, and an in vivo T2 weighted magnetic resonance imaging (MRI) for the same individual marmoset before surgery. The CT image is manually aligned to the in vivo MRI space by rigid transformation using AFNI software (Cox, 1996). The electrodes are manually segmented from the CT images using 3D Slicer (Fedorov et al., 2012) to eliminate non-electrode regions and numbering the electrodes.


#### 2. Registration to the standard space

![](docs/Annotation2.png)

The in vivo individual MRI (subject space) is registered to the in vivo average MRI data of marmosets by free-form deformation using ANTs software (Avants et al, 2011). The in vivo averaged MRI data is also registered to the standard space defined by BMA 2019 Ex vivo using ANTs software. Then, we map the segmented electrode on the subject space to those on the standard space based on these registrations. Finally we determine a nearest voxel of each electrode on the standard brain using a nearest neighbor method, and annotate a cortical region of the voxel to the electrode.

### Contents of Data

Each ElectrodesXx.zip archive contains `ElectrodesXx.mat` and `ElectrodeIndexXx.csv` files.

#### 1. `ElectrodesXx.mat`

Information of the ECoG electrode locations on a 2D subject space.

* MRI: 2D view of the marmoset brain
* LINE: The outline of the marmoset brain
* X: X positions of the electrodes
* Y: Y positions of the electrodes

optionally:
* LX: X positions of the LEDs
* LY: Y positions of the LEDs
* IX: X positions of the virus injections
* IY: Y positions of the virus injections

#### 2. `ElectrodesIndexXx.csv`

Information of the ECoG electrode on the standard space.

* Column 1: segment number
* Column 2: segment name
* Column 3: area number based on Hashikawa Atlas
* Column 4: area abbreviation
* Column 5: area name
* Column 6: hemisphere
* Column 7-9: RAS coordinates on the standard space


## CITATION

Nakae, Ken; Komatsu, Misako; Kaneko, Takaaki; Hata, Junichi; Okano, Hideyuki; Ishii, Shin; Yamamori, Tetsuo : _Brain/MINDS Marmoset Brain ECoG Annotations of Electrodes (DataID: 4958)_

## LICENSE

This work is licensed under a [Creative Commons Attribution 4.0 International License](http://creativecommons.org/licenses/by/4.0/).

## CONTENT

|Data Name|Data Type|Marmoset ID|Electrode Type|
| ---- | ---- | ---- | ---- |
|[`ElectrodesKr.zip`](ElectrodesKr.zip)|MAT, CSV|R02_9024_CM515M|R64+8bLED|
|[`ElectrodesMr.zip`](ElectrodesMr.zip)|MAT, CSV|R02_0003_CM943M|L96v1|
|[`ElectrodesOr.zip`](ElectrodesOr.zip)|MAT, CSV|R03_0035_CM814F|R96v1|
|[`ElectrodesPr.zip`](ElectrodesPr.zip)|MAT, CSV|R04_0070_CM962F|R64|
|[`ElectrodesJi.zip`](ElectrodesJi.zip)|MAT, CSV|R03_0024_CM622M|L96v2|
|[`ElectrodesQc.zip`](ElectrodesQc.zip)|MAT, CSV|R01_0074_CM1066F|R96v1|
|[`ElectrodesRc.zip`](ElectrodesRc.zip)|MAT, CSV|R03_0044_CM997M|R96v2|
|[`ElectrodesSs.zip`](ElectrodesSs.zip)|MAT, CSV|R03_0070_CM1002M|R96v2|
|[`ElectrodesNr.zip`](ElectrodesNr.zip)|MAT, CSV|R02_0043_CM1129F|L96v2|
|[`ElectrodesTk.zip`](ElectrodesTk.zip)|MAT, CSV|R03_0040_CM929M|L96v2+16bLED|

